Re: ESC-$ fails on ispell version check

2005-12-12 Thread Kim F. Storm
Eli Zaretskii [EMAIL PROTECTED] writes:

 From: Kim F. Storm [EMAIL PROTECTED]
 Date: Fri,  9 Dec 2005 15:27:52 +0100 (CET)
 
 I guess the problem is with version-to-list not accepting the aspell
 version string.

 Yes.

 Perhaps it should interpret .n as 0.n ?

 I won't have any objections to such a change.

I have installed a fix.

-- 
Kim F. Storm [EMAIL PROTECTED] http://www.cua.dk



___
emacs-pretest-bug mailing list
emacs-pretest-bug@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-pretest-bug


Re: :family extension for make_network_process

2005-12-12 Thread Kim F. Storm
Kazu Yamamoto (山本和彦) [EMAIL PROTECTED] writes:

 Hello, 

 I would report one documentation mistake and propose an extension for
 make_network_process.

I looked at your patch, and I cannot get it to fit precisely to what
you describe below:


 DOC: 

 Recently many OSes have implemented getaddrinfo. In this case, AF_UNSPEC
 is used. Thus, the documentation of the :family arguments should be
   The default address family is IPv6 or IPv4

Better would be:

The default address family is one of IPv4 or IPv6 depending on what
the name server returns as the primary address for the host.


 instead of
   The default address family is Inet (or IPv4).

 EXTENSION:

 Since nil for :family cannot ensure to choose IPv4, 

It can!  The default family is used only if :family is NOT present,
whereas :family nil means AF_INET.  So only inet6 is really needed.

In any case, your interface is probably better for clarity.  So:

:family nil == :family omitted == use default
:family 'ipv4 = force IPv4
:family 'ipv6 = force IPv6

I think it is clearer to use ipv4 and ipv6 rather than inet and inet6.

 I would propose
 two more symbols for the :family arguments:
   'inet for IPv4
   'inet6 for IPv6

 Note the :family arguments: can take an integer but it is not
 practical to tell the value of AF_INET (or AF_INET6) from the Elisp
 level in ALL environments.

True -- this is intended as a low-level interface to allow the use of
other address families which are not known to emacs.

 The following is a sample code to implement this. Please merge this
 code if possible.

Thanks for the patch, but I will implement it a little differently.
And update the documentation accordingly...

-- 
Kim F. Storm [EMAIL PROTECTED] http://www.cua.dk



___
emacs-pretest-bug mailing list
emacs-pretest-bug@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-pretest-bug


isearch-query-replace: empty search

2005-12-12 Thread aaron . hawley

Typing `C-s M-%' or `C-s C-M-%' gives the error:

  isearch-query-replace: Wrong type argument: number-or-marker-p, nil

Here's a patch:

--- isearch.el  28 Nov 2005 12:43:16 -0500  1.276
+++ isearch.el  12 Dec 2005 10:38:02 -0500  
@@ -1222,7 +1222,8 @@
   (let ((case-fold-search isearch-case-fold-search))
 (isearch-done)
 (isearch-clean-overlays)
-(if (and ( isearch-other-end (point))
+(if (and isearch-other-end
+( isearch-other-end (point))
  (not (and transient-mark-mode mark-active
( isearch-opoint (point)
 (goto-char isearch-other-end))


In GNU Emacs 22.0.50.1 (i486-pc-linux-gnu, X toolkit, Xaw3d scroll bars)
 of 2005-12-07 on pacem, modified by Debian
X server distributor `The X.Org Foundation', version 11.0.60802000
configured using `configure '--build' 'i486-linux-gnu' '--host' 
'i486-linux-gnu' '--prefix=/usr' '--sharedstatedir=/var/lib' 
'--libexecdir=/usr/lib' '--localstatedir=/var' '--infodir=/usr/share/info' 
'--mandir=/usr/share/man' '--with-pop=yes' 
'--enable-locallisppath=/etc/emacs-snapshot:/etc/emacs:/usr/local/share/emacs/22.0.50/site-lisp:/usr/local/share/emacs/site-lisp:/usr/share/emacs/22.0.50/site-lisp:/usr/share/emacs/site-lisp:/usr/share/emacs/22.0.50/leim'
 '--with-x=yes' '--with-x-toolkit=athena' '--with-toolkit-scroll-bars' 
'CFLAGS=-DDEBIAN -g -Wno-pointer-sign -O2' 'build_alias=i486-linux-gnu' 
'host_alias=i486-linux-gnu''

Important settings:
  value of $LC_ALL: nil
  value of $LC_COLLATE: nil
  value of $LC_CTYPE: nil
  value of $LC_MESSAGES: nil
  value of $LC_MONETARY: nil
  value of $LC_NUMERIC: nil
  value of $LC_TIME: nil
  value of $LANG: nil
  locale-coding-system: nil
  default-enable-multibyte-characters: t

Minor modes in effect:
  tooltip-mode: t
  auto-compression-mode: t
  tool-bar-mode: t
  mouse-wheel-mode: t
  menu-bar-mode: t
  file-name-shadow-mode: t
  global-font-lock-mode: t
  font-lock-mode: t
  blink-cursor-mode: t
  unify-8859-on-encoding-mode: t
  utf-translate-cjk-mode: t
  line-number-mode: t


___
emacs-pretest-bug mailing list
emacs-pretest-bug@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-pretest-bug


Re: build failure on Irix 6.5/gcc

2005-12-12 Thread Dave Love
Richard M. Stallman [EMAIL PROTECTED] writes:

 We are interested...in installing a fix, but there may not be anyone
 here who uses that system, so we can only wait till someone sends us a
 fix.

I don't understand why you now seem to reject anything from me.
Anyone else's fix has to do the same thing, and they will just have
wasted time if they don't see my mail about it.  That's already
happened in other areas where I've tried to contribute.

You don't have to believe me about unexec since what gcc does with
.data.rel (and its equivalence to .sdata) is clear from grepping gcc's
source.  If you don't believe me about conservative gc on Irix, you
should remove the settings for it in s/irix6-0.h.  As the comments
say, the testing was actually on Irix 6.5 and the settings were meant
to be in the 6.5 configuration.

I realized NO_REMAP isn't used on ELF systems, though, so actually it
doesn't need conditionalizing in iris4d.h.


___
emacs-pretest-bug mailing list
emacs-pretest-bug@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-pretest-bug


Re: :family extension for make_network_process

2005-12-12 Thread Kim F. Storm

Kazu Yamamoto (山本和彦) [EMAIL PROTECTED] writes:

 I would report one documentation mistake and propose an extension for
 make_network_process.

Does the following patch give good results?

*** process.c   01 Oct 2005 21:33:29 +0200  1.467
--- process.c   12 Dec 2005 15:35:44 +0100  
***
*** 140,146 
  Lisp_Object Qprocessp;
  Lisp_Object Qrun, Qstop, Qsignal;
  Lisp_Object Qopen, Qclosed, Qconnect, Qfailed, Qlisten;
! Lisp_Object Qlocal, Qdatagram;
  Lisp_Object QCname, QCbuffer, QChost, QCservice, QCtype;
  Lisp_Object QClocal, QCremote, QCcoding;
  Lisp_Object QCserver, QCnowait, QCnoquery, QCstop;
--- 140,149 
  Lisp_Object Qprocessp;
  Lisp_Object Qrun, Qstop, Qsignal;
  Lisp_Object Qopen, Qclosed, Qconnect, Qfailed, Qlisten;
! Lisp_Object Qlocal, Qipv4, Qdatagram;
! #ifdef AF_INET6
! Lisp_Object Qipv6;
! #endif
  Lisp_Object QCname, QCbuffer, QChost, QCservice, QCtype;
  Lisp_Object QClocal, QCremote, QCcoding;
  Lisp_Object QCserver, QCnowait, QCnoquery, QCstop;
***
*** 2595,2604 
  stream type connection, `datagram' creates a datagram type connection.
  
  :family FAMILY -- FAMILY is the address (and protocol) family for the
! service specified by HOST and SERVICE.  The default address family is
! Inet (or IPv4) for the host and port number specified by HOST and
! SERVICE.  Other address families supported are:
local -- for a local (i.e. UNIX) address specified by SERVICE.
  
  :local ADDRESS -- ADDRESS is the local address used for the connection.
  This parameter is ignored when opening a client process. When specified
--- 2598,2610 
  stream type connection, `datagram' creates a datagram type connection.
  
  :family FAMILY -- FAMILY is the address (and protocol) family for the
! service specified by HOST and SERVICE.  The default (nil) is to use
! whatever address family (IPv4 or IPv6) that is defined for the host
! and port number specified by HOST and SERVICE.  Other address families
! supported are:
local -- for a local (i.e. UNIX) address specified by SERVICE.
+   ipv4  -- use IPv4 address family only.
+   ipv6  -- use IPv6 address family only.
  
  :local ADDRESS -- ADDRESS is the local address used for the connection.
  This parameter is ignored when opening a client process. When specified
***
*** 2855,2873 
  
/* :family FAMILY -- nil (for Inet), local, or integer.  */
tem = Fplist_get (contact, QCfamily);
!   if (INTEGERP (tem))
! family = XINT (tem);
!   else
  {
!   if (NILP (tem))
!   family = AF_INET;
! #ifdef HAVE_LOCAL_SOCKETS
!   else if (EQ (tem, Qlocal))
!   family = AF_LOCAL;
  #endif
  }
!   if (family  0)
  error (Unknown address family);
ai.ai_family = family;
  
/* :service SERVICE -- string, integer (port number), or t (random port).  
*/
--- 2861,2889 
  
/* :family FAMILY -- nil (for Inet), local, or integer.  */
tem = Fplist_get (contact, QCfamily);
!   if (NILP (tem))
  {
! #ifdef HAVE_GETADDRINFO
!   family = AF_UNSPEC;
! #else
!   family = AF_INET;
  #endif
  }
! #ifdef HAVE_LOCAL_SOCKETS
!   else if (EQ (tem, Qlocal))
! family = AF_LOCAL;
! #endif
! #ifdef AF_INET6
!   else if (EQ (tem, Qipv6))
! family = AF_INET6;
! #endif
!   else if (EQ (tem, Qipv4))
! family = AF_INET;
!   else if (INTEGERP (tem))
! family = XINT (tem);
!   else
  error (Unknown address family);
+ 
ai.ai_family = family;
  
/* :service SERVICE -- string, integer (port number), or t (random port).  
*/
***
*** 2933,2939 
QUIT;
memset (hints, 0, sizeof (hints));
hints.ai_flags = 0;
!   hints.ai_family = NILP (Fplist_member (contact, QCfamily)) ? AF_UNSPEC 
: family;
hints.ai_socktype = socktype;
hints.ai_protocol = 0;
ret = getaddrinfo (SDATA (host), portstring, hints, res);
--- 2949,2955 
QUIT;
memset (hints, 0, sizeof (hints));
hints.ai_flags = 0;
!   hints.ai_family = family;
hints.ai_socktype = socktype;
hints.ai_protocol = 0;
ret = getaddrinfo (SDATA (host), portstring, hints, res);
***
*** 6724,6729 
--- 6740,6749 
  #ifdef HAVE_LOCAL_SOCKETS
 ADD_SUBFEATURE (QCfamily, Qlocal);
  #endif
+ADD_SUBFEATURE (QCfamily, Qipv4);
+ #ifdef AF_INET6
+ADD_SUBFEATURE (QCfamily, Qipv6);
+ #endif
  #ifdef HAVE_GETSOCKNAME
 ADD_SUBFEATURE (QCservice, Qt);
  #endif
***
*** 6782,6787 
--- 6802,6813 
staticpro (Qlisten);
Qlocal = intern (local);
staticpro (Qlocal);
+   Qipv4 = intern (ipv4);
+   staticpro (Qipv4);
+ #ifdef AF_INET6
+   Qipv6 = intern (ipv6);
+   staticpro (Qipv6);
+ #endif
Qdatagram = intern (datagram);
staticpro (Qdatagram);
  
-- 
Kim F. Storm [EMAIL PROTECTED] http://www.cua.dk



___
emacs-pretest-bug mailing list
emacs-pretest-bug@gnu.org

Re: Interactive specs

2005-12-12 Thread Stefan Monnier
 After the release, I think it calls for a different approach.  For
 instance, we could write

(interactive
  (list (recompute-arg EXPRESSION) (recompute-arg EXPRESSION) ...))

 When evaluated, recompute-arg would return its arg, but when
 fix_command sees it, it would save EXPRESSION as the value.

That would be better indeed.  But it still would force us to use (list ...)
which is sometimes fairly inconvenient.

Maybe we could instead define recompute-arg as

  (defmacro recompute-arg (e)
`(list 'recompute-arg-tag ,e ',e))

and then we don't need to look inside the interactive spec at all: we can
just look at the argument's values and treat values of the form
(recompute-arg-tag V E) specially.  And interactive specs can thus be
deinfed in any way we like, including calling a function shared among
several commands, ...


Stefan


___
emacs-pretest-bug mailing list
emacs-pretest-bug@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-pretest-bug


Re: find-file sometimes doesn't

2005-12-12 Thread Bill Wohler
Stefan Monnier [EMAIL PROTECTED] wrote:

  In the last week, sometimes maybe 1 in 20 times, C-x C-f (find-file)
  RET won't find the given file. However, the symptom is that if I'm
  editing buffer foo, and run find-file to open file bar, instead of
  getting two equally-sized windows containing foo and bar, I get two
  foo windows, one of which is only three lines high.
  
  Is this reproducible?
 
  Yes! If you find a file that is under revision control that you do not
  have permission to edit, you get the following:
 
 I can't reproduce it here.  Is it true for any revision control system, or
 did you use a specific one?

I'm using Subversion. I don't have any ready examples from other systems
at the moment. However, keep reading.

  If so, can you please debug it?
 
  Not completely. I tracked the problem down to find-file-name-handler
  setting buffer-file-name to nil (maybe that's enough info to remind
  someone of a change they made in the past couple of weeks).  Here's the
  stack at that time:
 
 Le code of find-file-name-handler doesn't seem to leave much possibility for
 buffer-file-name to be set to nil.  What makes you think that's where the
 variable is nil'd ?

Twilight zone. I could have sworn that `e' of buffer-file-name before
the call showed the file name and an `e' of buffer-file-name after the
call showed nil but now I find that it was a different problem which I
was able to fix.

Here is the patch which I just checked in and ChangeLog entry which
explains it. Please review.


2005-12-12  Bill Wohler  [EMAIL PROTECTED]

* vc-svn.el (vc-svn-registered): Fix problem of visiting
non-writable Subversion-controlled files by saving window
configuration before calling vc-do-command. vc-do-command calls
pop-to-buffer on error which is unexpected during registration.

Index: vc-svn.el
===
RCS file: /cvsroot/emacs/emacs/lisp/vc-svn.el,v
retrieving revision 1.22
diff -u -r1.22 vc-svn.el
--- vc-svn.el   14 Nov 2005 04:33:03 -  1.22
+++ vc-svn.el   13 Dec 2005 00:42:59 -
@@ -114,13 +114,18 @@
   (file-name-directory file)))
 (with-temp-buffer
   (cd (file-name-directory file))
-  (condition-case nil
- (vc-svn-command t 0 file status -v)
-   ;; Some problem happened.  E.g. We can't find an `svn' executable.
-;; We used to only catch `file-error' but when the process is run on
-;; a remote host via Tramp, the error is only reported via the
-;; exit status which is turned into an `error' by vc-do-command.
-   (error nil))
+(condition-case nil
+;; Save configuration since vc-do-command calls pop-to-buffer on
+;; error (such as visiting a Subversion-controlled file that you
+;; don't have permission to edit). This causes later problems
+;; during registration.
+(save-window-excursion
+  (vc-svn-command t 0 file status -v))
+  ;; Some problem happened.  E.g. We can't find an `svn' executable.
+  ;; We used to only catch `file-error' but when the process is run on
+  ;; a remote host via Tramp, the error is only reported via the
+  ;; exit status which is turned into an `error' by vc-do-command.
+  (error nil))
   (vc-svn-parse-status t)
   (eq 'SVN (vc-file-getprop file 'vc-backend)
 

-- 
Bill Wohler [EMAIL PROTECTED]  http://www.newt.com/wohler/  GnuPG ID:610BD9AD
Maintainer of comp.mail.mh FAQ and MH-E. Vote Libertarian!
If you're passed on the right, you're in the wrong lane.


___
emacs-pretest-bug mailing list
emacs-pretest-bug@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-pretest-bug


Re: build failure on Irix 6.5/gcc

2005-12-12 Thread Richard M. Stallman
I don't understand why you now seem to reject anything from me.

I appreciate your work.  If you send a useful and clear bug fix, we
will certainly use it.  At times when we want new features, we would
be glad accept them from you too (assuming we like the features).

You don't have to believe me about unexec since what gcc does with
.data.rel (and its equivalence to .sdata) is clear from grepping gcc's
source.

Did you send a patch for this that we neglected?
If so, could you please send it again?


___
emacs-pretest-bug mailing list
emacs-pretest-bug@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-pretest-bug


Re: Interactive specs

2005-12-12 Thread Richard M. Stallman
Maybe we could instead define recompute-arg as

  (defmacro recompute-arg (e)
`(list 'recompute-arg-tag ,e ',e))

and then we don't need to look inside the interactive spec at all: we can
just look at the argument's values and treat values of the form
(recompute-arg-tag V E) specially.

I don't understand how you propose to use that macro.


___
emacs-pretest-bug mailing list
emacs-pretest-bug@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-pretest-bug


Re: :family extension for make_network_process

2005-12-12 Thread 山本和彦
Hello,

From: [EMAIL PROTECTED] (Kim F. Storm)
Subject: Re: :family extension for make_network_process

  I would report one documentation mistake and propose an extension for
  make_network_process.
 
 Does the following patch give good results?

Yes. This code is much better than mine.
Thanks!

--Kazu


___
emacs-pretest-bug mailing list
emacs-pretest-bug@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-pretest-bug